package Task::Software::Catalog::SW;

our $DATE = '2018-11-04'; # DATE
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: All Software::Catalog::SW::* modules

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::Software::Catalog::SW - All Software::Catalog::SW::* modules

=head1 VERSION

version 0.001

=head1 TASK CONTENTS

=head2 Included modules

=head3 L<Software::Catalog::SW::bulwark::qt>

=head3 L<Software::Catalog::SW::dummy::undownloadable>

=head3 L<Software::Catalog::SW::firefox>

=head3 L<Software::Catalog::SW::zcoin::qt>

=head3 L<Software::Catalog::SW::zotero>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
